/*
 * (C) Copyright 2000-2005 Hewlett-Packard Development Company, L.P.
 */
#ifndef CI_WRAP 
#define CI_WRAP 

//#ifdef LINUX

#ifndef NULL
#define NULL ((void*)0)
#endif

//int printk(const char*, ...);


#ifdef DEBUG_INTR
#ifdef __KERNEL__
	#define DBG_INTR( fmt, args...) printk(fmt, ##args);
#else
	#define DBG_INTR( fmt, args...) printf(fmt, ##args);
#endif
#else
#define DBG_INTR( fmt, args...) 
#endif

#ifdef CPQCI_DEBUG
#ifdef __KERNEL__
	#define DBG( fmt, args...) printk(fmt, ##args);
#else
	#define DBG( fmt, args...) printf(fmt, ##args);
#endif
#else
#define DBG( fmt, args...) 
#endif

//#if (LINUX_VERSION_CODE >= 0x020300) && !(defined(SLES7))
#define PRINTF(fmt, args...)\
buflen+=CpqCiSNPrintf(buffer+buflen, bufsize-buflen, fmt, ##args);
//#else
//#define PRINTF(fmt, args...)\
//if (bufsize-buflen > 256) {\
//	buflen+=CpqCiSPrintf(buffer+buflen, fmt, ##args);\
//}
//#endif

//#endif /* Linux */

#endif /* WRAP */
